@@ -22,11 +22,11 @@ backtick_binaries<-function(vec_of_strings){
 #'Runs Monte Carlo. For details see documentation of wrapper function.
 #'@keywords internal
 #'@importFrom utils txtProgressBar
+#'@import rlecuyer
 #'@import snow
 #'@import snowfall
-#'@import rlecuyer
-
-MC_inner<-function(func, nrep, param_list, ret_vals, ncpus=2,  max_grid=1000, packages=NULL, export_functions=NULL){
+#'@importFrom snow setDefaultClusterOptions
+MC_inner<-function(func, nrep, param_list, ret_vals, ncpus=1,  max_grid=1000, packages=NULL, export_functions=NULL){
   #, debug=FALSE
   
   # ------- extract information from parameter list
@@ -48,7 +48,9 @@ MC_inner<-function(func, nrep, param_list, ret_vals, ncpus=2,  max_grid=1000, pa
   
   #------- setup progress bar
   
-  if(ncpus>1){cat(paste("Simulation parallelized using",ncpus, "cpus.","\n","\n"))}
+  if(ncpus>1){
+    cat(paste("Simulation parallelized using",ncpus, "cpus.","\n","\n"))
+  }
   cat(paste("Progress:","\n","\n"))
   pb <- txtProgressBar(min=0, max=grid_size, style=3)
   
@@ -79,14 +81,14 @@ MC_inner<-function(func, nrep, param_list, ret_vals, ncpus=2,  max_grid=1000, pa
   s1<-paste(paste(c(paste("for(",index, " in 1:", dim_vec,"){", sep="",collapse="")),collapse=""),assign_param_values, sep="",collapse="")
   
   in_export<-paste("'",c('func2','func','libloc_strings',export_functions,param_names),"'", collapse=",", sep="")
-  aux.s2<-paste("if(ncpus>1){sfExport(",in_export,")};",sep="")
+  aux.s2<-paste("if(ncpus>1){snowfall::sfExport(",in_export,")};",sep="")
   
-  s2<-paste("suppressMessages(sfInit(parallel=if(ncpus>1){TRUE}else{FALSE}, cpus = ncpus, type= 'SOCK'));",
+  s2<-paste("suppressMessages(snowfall::sfInit(parallel=if(ncpus>1){TRUE}else{FALSE}, cpus = ncpus, type= 'SOCK'));",
             aux.s2,"sfClusterEval(.libPaths(libloc_strings));",
-            if(length(packages)>0){paste("capture.output(suppressMessages(sfLibrary(",packages,")));", sep="", collapse="")}else{""},
+            if(length(packages)>0){paste("capture.output(suppressMessages(snowfall::sfLibrary(",packages,")));", sep="", collapse="")}else{""},
             'seed<-as.numeric(paste(sample(0:9,5,replace=TRUE), collapse=""));',
-            if(ncpus>1){"sfClusterSetupRNG(seed=rep(seed,6));"}else{""},
-            "erg<-sfApply(as.matrix(1:nrep,nrep,1),margin=1,fun=func2,",subm_param,");suppressMessages(sfStop());",sep="", collapse="")
+            if(ncpus>1){"snowfall::sfClusterSetupRNG(seed=rep(seed,6));"}else{""},
+            "erg<-snowfall::sfApply(as.matrix(1:nrep,nrep,1),margin=1,fun=func2,",subm_param,");suppressMessages(snowfall::sfStop());",sep="", collapse="")
   
   s3<-paste(paste(paste("results$",ret_vals,"[",sep=""),
             paste(paste(index,",", collapse="", sep=""),"]<-",sep="",collapse=""),sep=""),
@@ -170,6 +172,10 @@ MC_inner<-function(func, nrep, param_list, ret_vals, ncpus=2,  max_grid=1000, pa
 #' @import codetools
 #' @importFrom utils capture.output
 #' @importFrom utils packageDescription
+#' @importFrom utils txtProgressBar
+#' @import rlecuyer
+#' @import snow
+#' @import snowfall
 #' @examples
 #' test_func<-function(n,loc,scale){
 #'  sample<-rnorm(n, loc, scale)
@@ -203,7 +209,7 @@ MonteCarlo<-function(func, nrep, param_list, ncpus=1, max_grid=1000, time_n_test
   #mode<-mode[1] # , mode=c("longitudinal","cross-sectional")
   
   # -------- check whether arguments supplied to function are admissable 
-    
+  
   if(is.function(func)==FALSE)stop("func must be a function")
   if(is.list(param_list)==FALSE)stop("param_list must be a list containing the names of the function arguments and the vectors of values that are supposed to be passed as arguments.")
   for(i in 1:length(param_list)){if(is.vector(param_list[[i]])==FALSE)stop("Parameter grids have to be vectors.")}
@@ -270,6 +276,8 @@ MonteCarlo<-function(func, nrep, param_list, ncpus=1, max_grid=1000, time_n_test
   
   # -- add everything that is specified in export_also
   
+  globals_in_func$variables<-globals_in_func$variables[which(globals_in_func$variables%in%c("LETTERS","letters","month.abb", "month.name","pi")==FALSE)]
+  
   export_functions<-c(export_functions,export_also$functions,export_also$data, export_also$variables, globals_in_func$variables)
   
   # -------- Find out which packages have to be loaded into cluster
